@@ -1,5 +1,6 @@
 import os
 import time
+import argparse
 
 def isdigit(s, allowFloat=True, allowNegative=False):
     digits = '0123456789'
@@ -14,6 +15,7 @@ def isdigit(s, allowFloat=True, allowNegative=False):
     return True
 
 def countdown_display(secs):
+    secs = round(secs, 1)
     while secs >= 0:
         os.system('clear')
         m, s = divmod(secs, 60)
@@ -29,7 +31,7 @@ def countdown_display(secs):
     print('\033[0m', end='')
     return True
 
-def countdown(t):
+def countdown(t=15):
     t = str(t).replace(' ', '').replace('m', ':')
     if t[-1] == 's':
         t = t[:-1]
@@ -37,9 +39,25 @@ def countdown(t):
         return countdown_display(float(t))
     elif t.count(':') == 1:
         m, s = t.split(':')
+        if not s:
+            s = '0'
         if isdigit(m, False) and isdigit(s):
             secs = int(m)*60 + float(s)
+            return countdown_display(secs)
+        else:
+            return False
+    else:
+        return False
 
-def demo():
-    return countdown(15)
-        
+def countdown_terminal():
+    parser = argparse.ArgumentParser(prog ='countdown',
+                                     description ='countdown')
+
+    parser.add_argument('time', metavar ='time', type=str, nargs=1, help= 'time')
+
+    args = parser.parse_args()
+
+    if countdown(args[0]):
+        print('Countdown finished.')
+    else:
+        print('Countdown failed.')
